% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/rm_date.R
\name{rm_date}
\alias{rm_date}
\title{Remove/Replace/Extract Dates}
\usage{
rm_date(text.var, trim = !extract, clean = TRUE, pattern = "@rm_date",
  replacement = "", extract = FALSE,
  dictionary = getOption("regex.library"), ...)
}
\arguments{
\item{text.var}{The text variable.}

\item{trim}{logical.  If \code{TRUE} removes leading and trailing white
spaces.}

\item{clean}{trim logical.  If \code{TRUE} extra white spaces and escaped
character will be removed.}

\item{pattern}{A character string containing a regular expression (or
character string for \code{fixed = TRUE}) to be matched in the given
character vector (see \bold{Details} for additional information).  Default,
\code{@rm_date} uses the \code{rm_date} regex from the regular expression
dictionary from the \code{dictionary} argument.}

\item{replacement}{Replacement for matched \code{pattern}.}

\item{extract}{logical.  If \code{TRUE} the dates are extracted into a
list of vectors.}

\item{dictionary}{A dictionary of canned regular expressions to search within
if \code{pattern} begins with \code{"@rm_"}.}

\item{\dots}{Other arguments passed to \code{\link[base]{gsub}}.}
}
\value{
Returns a character string with dates removed.
}
\description{
Remove/replace/extract dates from a string in the form of (1) XX/XX/XXXX,
XX/XX/XX, XX-XX-XXXX, XX-XX-XX, XX.XX.XXXX, or XX.XX.XX OR
(2) March XX, XXXX or Mar XX, XXXX OR (3) both forms.
}
\details{
The default regular expression used by \code{rm_date} finds numeric
representations not word/abbreviations.  This means that
\code{"June 13, 2002"} is not matched.  This behavior can be altered (to
include month names/abbreviations) by using a secondary regular expression
from the \code{\link[qdapRegex]{regex_usa}} data (or other dictionary) via
(\code{pattern = "@rm_date2"}, \code{pattern = "@rm_date3"}, or
\code{pattern = "@rm_date4"}). See
\bold{Examples} for example usage.
}
\examples{
## Numeric Date Representation

x <- paste0("Format dates as 04/12/2014, 04-12-2014, 04.12.2014. or",
    " 04/12/14 but leaves mismatched: 12.12/2014")
rm_date(x)
rm_date(x, extract=TRUE)

## Word/Abbreviation Date Representation

x2 <- paste0("Format dates as Sept 09, 2002 or October 22, 1887",
  "but not 04-12-2014 and may match good 00, 9999")
rm_date(x2, pattern="@rm_date2")
rm_date(x2, pattern="@rm_date2", extract=TRUE)


## Year-Month-Day Representation
x3 <- sprintf("R uses time in this format \%s.", Sys.time())
rm_date(x3, pattern="@rm_date3")

## Grab all types
rm_date(c(x, x2, x3), pattern="@rm_date4", extract=TRUE)
}
\seealso{
\code{\link[base]{gsub}},
\code{\link[stringi]{stri_extract_all_regex}}

Other rm_.functions: \code{\link{as_numeric}},
  \code{\link{as_numeric2}}, \code{\link{rm_number}};
  \code{\link{as_time}}, \code{\link{as_time2}},
  \code{\link{rm_time}}, \code{\link{rm_transcript_time}};
  \code{\link{rm_abbreviation}}; \code{\link{rm_angle}},
  \code{\link{rm_bracket}},
  \code{\link{rm_bracket_multiple}},
  \code{\link{rm_curly}}, \code{\link{rm_round}},
  \code{\link{rm_square}}; \code{\link{rm_between}},
  \code{\link{rm_between_multiple}};
  \code{\link{rm_caps_phrase}}; \code{\link{rm_caps}};
  \code{\link{rm_citation_tex}}; \code{\link{rm_citation}};
  \code{\link{rm_city_state_zip}};
  \code{\link{rm_city_state}}; \code{\link{rm_default}};
  \code{\link{rm_dollar}}; \code{\link{rm_email}};
  \code{\link{rm_emoticon}}; \code{\link{rm_endmark}};
  \code{\link{rm_hash}}; \code{\link{rm_nchar_words}};
  \code{\link{rm_non_ascii}}; \code{\link{rm_non_words}};
  \code{\link{rm_percent}}; \code{\link{rm_phone}};
  \code{\link{rm_postal_code}};
  \code{\link{rm_repeated_characters}};
  \code{\link{rm_repeated_phrases}};
  \code{\link{rm_repeated_words}}; \code{\link{rm_tag}};
  \code{\link{rm_title_name}};
  \code{\link{rm_twitter_url}}, \code{\link{rm_url}};
  \code{\link{rm_white}}, \code{\link{rm_white_bracket}},
  \code{\link{rm_white_colon}},
  \code{\link{rm_white_comma}},
  \code{\link{rm_white_endmark}},
  \code{\link{rm_white_lead}},
  \code{\link{rm_white_lead_trail}},
  \code{\link{rm_white_multiple}},
  \code{\link{rm_white_punctuation}},
  \code{\link{rm_white_trail}}; \code{\link{rm_zip}}
}
\keyword{date}

